"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateApiSignature = void 0;
const crypto_1 = __importDefault(require("crypto"));
/**
 * generateApiSignature
 *  - NCP API Signature Constructor
 *  - external API Doc : https://api.ncloud-docs.com/docs/en/common-ncpapi
 *
 * @param {string} method - NCP API service method
 * @param {string} url - NCP API service url ( include query string )
 * @param {NCPAuthKeyType} ncpAuthKey - NCP Account access key & secret key ( from portal or Sub Account )
 *
 * @return {ApiSignatureReturnType}
 *         Caculated api signature for NCP services
 *         Format : { Current_timestamp, Caculated_signature }
 */
function generateApiSignature({ method, url, ncpAuthKey }) {
    const { accessKey, secretKey } = ncpAuthKey;
    const signParams = [];
    const space = ' '; // one space
    const newLine = '\n'; // new line
    var timestamp = Date.now().toString(); // current timestamp (epoch)
    var hmac = crypto_1.default.createHmac('sha256', secretKey);
    signParams.push(method);
    signParams.push(space);
    signParams.push(url);
    signParams.push(newLine);
    signParams.push(timestamp);
    signParams.push(newLine);
    signParams.push(accessKey);
    const signature = hmac.update(signParams.join('')).digest('base64');
    return {
        timestamp,
        signature
    };
}
exports.generateApiSignature = generateApiSignature;
