import { AxiosResponse, Method } from 'axios';
import { NCPAuthKeyType } from './types';
/**
 *
 *
 * @export
 * @class NCPClient
 */
export declare class NCPClient {
    /**
     * The account access Key for API authentication
     *
     * @type {string}
     * @memberof NCPClient
     */
    readonly ncpAuthKey: NCPAuthKeyType;
    /**
     * The axios instance for Web Client
     *
     * @private
     * @type {AxiosInstance}
     * @memberof NCPClient
     */
    private client;
    /**
     * Creates an instance of ApiClient.
     *
     * @memberof NCPClient
     */
    constructor(ncpAuthKey: NCPAuthKeyType, baseUrl: string);
    /**
     * ApiRequest execution
     *
     * @param {ApiRequest} endpoint - ApiRequest configs for http request
     * @returns {Promise<AxiosResponse>} - return Promise response of http request with current ApiRequest configs
     *
     */
    request(endpoint: ApiRequest): Promise<AxiosResponse>;
}
/**
 * Interface for ApiRequest configs
 */
export interface ApiRequest {
    path: string;
    method: Method;
    headers: {
        [key: string]: string;
    };
    body?: {
        [key: string]: any;
    };
}
/**
 * Enum for representation of http status error code which provided by NCP API.
 * @readonly
 * @enum {number}
 */
export declare enum ApiError {
    badRequest = 400,
    unauthorized = 401,
    forbidden = 403,
    notFound = 404,
    tooManyRequests = 429,
    internalServerError = 500
}
export declare enum BaseURL {
    sens = "https://sens.apigw.ntruss.com"
}
