"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseURL = exports.ApiError = exports.NCPClient = void 0;
const axios_1 = __importDefault(require("axios"));
//  sms : `https://sens.apigw.ntruss.com/sms/v2/services/${serviceId}/messages`
//  push : `https://sens.apigw.ntruss.com/push/v2/services/${serviceId}/users`
/**
 *
 *
 * @export
 * @class NCPClient
 */
class NCPClient {
    /**
     * Creates an instance of ApiClient.
     *
     * @memberof NCPClient
     */
    constructor(ncpAuthKey, baseUrl) {
        this.ncpAuthKey = ncpAuthKey;
        this.client = axios_1.default.create({
            baseURL: baseUrl,
            timeout: 2000
        });
    }
    /**
     * ApiRequest execution
     *
     * @param {ApiRequest} endpoint - ApiRequest configs for http request
     * @returns {Promise<AxiosResponse>} - return Promise response of http request with current ApiRequest configs
     *
     */
    async request(endpoint) {
        const { path, method, headers, body } = endpoint;
        return this.client.request({
            url: path,
            method: method,
            headers: headers,
            data: body
        });
    }
}
exports.NCPClient = NCPClient;
/**
 * Enum for representation of http status error code which provided by NCP API.
 * @readonly
 * @enum {number}
 */
var ApiError;
(function (ApiError) {
    ApiError[ApiError["badRequest"] = 400] = "badRequest";
    ApiError[ApiError["unauthorized"] = 401] = "unauthorized";
    ApiError[ApiError["forbidden"] = 403] = "forbidden";
    ApiError[ApiError["notFound"] = 404] = "notFound";
    ApiError[ApiError["tooManyRequests"] = 429] = "tooManyRequests";
    ApiError[ApiError["internalServerError"] = 500] = "internalServerError";
})(ApiError = exports.ApiError || (exports.ApiError = {}));
var BaseURL;
(function (BaseURL) {
    BaseURL["sens"] = "https://sens.apigw.ntruss.com";
})(BaseURL = exports.BaseURL || (exports.BaseURL = {}));
